
### Description

A metaphor is a figure of speech in which one concept (the "image") stands for another concept (the "topic"). That is, the topic is spoken of as if it were the image. For example, someone might say,

* The girl I love is a red rose.

Here the topic is "the girl I love," and the image is "a red rose." The girl is spoken of as if she were a red rose.

Anything in a language can serve as a metaphor. For example, verb forms can be used in unusual ways, as in,

* The Apostle Paul tells us that Christians will rise to life again.

In this case, the English present tense form "tells" is a metaphor for the past tense form "told," because the Apostle Paul lived long ago.

Sometimes speakers use metaphors that are very common in their language. However, sometimes speakers use metaphors that are uncommon, and even some metaphors that are unique.

Speakers most often use metaphors in order to strengthen their message, to express their feelings better, to say something that is hard to say in any other way, or to help people remember their message.

#### Kinds of Metaphors

There are several kinds of metaphors: "live" metaphors, "dead" metaphors, and patterned metaphors.

**Live Metaphors**

These are metaphors that people recognize as one concept standing for another concept. People also easily recognize them as giving strength and unusual qualities to the message. For this reason, people pay attention to these metaphors. For example,

> For you who fear my name, the sun of righteousness will rise with healing in its wings. (Malachi 4:2 ULB)

Here God speaks about his salvation as if it were the sun rising in order to shine its rays on the people whom he loves. He also speaks of the sun's rays as if they were wings. Also, he speaks of these wings as if they were bringing medicine that would heal his people.

Here is another example:
Jesus said, 'Go and tell that fox...,'" where "that fox" refers to King Herod. The people listening to Jesus certainly understood that Jesus was referring to Herod either as a very evil, cunning person or as a king who was only pretending to be great.

**Dead Metaphors**

A dead metaphor is a metaphor that has been used so much in the language that its speakers no longer regard it as one concept standing for another. Examples in English are "table leg," "family tree," "leaf" meaning a page in a book, and "crane" meaning a large machine for lifting heavy loads. English speakers simply think of these words as having more than one meaning. Examples in Biblical Hebrew are probably "heal" meaning "repair," and "sick" meaning "spiritually powerless because of sin."

**Patterned Pairs of Concepts acting as Metaphors**

Many ways of metaphorical speaking depend on pairs of concepts, where one underlying concept frequently stands for a different underlying concept. For example, in English, the direction UP often stands for the concept of MORE. Because of this pair of underlying concepts, we can make sentences such as "The price of gasoline is going *up*," "A *highly* intelligent man," and also the opposite kind of idea: "The heat is going *down*," and "The stock market *took a tumble*."

Patterned pairs of concepts are constantly used for metaphorical purposes in the world's languages, because they serve as convenient ways to organize thought. In general, people like to speak of abstract qualities, such as power, presence, emotions, and moral qualities, as if they were objects that could be seen or held, as if they were body parts, or as if they were events that could be watched as they happened.

When these metaphors are used in normal ways, it is rare that the speaker and audience regard them as figurative speech. Examples of metaphors in English that go unrecognized are:

* "Turn the heat *up*."  MORE is spoken of as UP.
* "Let us *go ahead* with our debate."  DOING WHAT WAS PLANNED is spoken of as WALKING or ADVANCING.
* "You *defend* your theory well." ARGUMENT is spoken of as WAR.
* "A *flow* of words" WORDS are spoken of as LIQUIDS.

English speakers do not view them as unusual expressions, so it would be wrong to translate them into other languages in a way that would lead people to pay special attention to them as figurative speech. 

For a description of important patterns of this kind of metaphor in biblical languages, please see [Biblical Imagery - Common Patterns](../bita-part1/01.md)and the pages it will direct you to.


#### Parts of a Metaphor

When talking about metaphors, it can be helpful to talk about their parts. A metaphor has three parts. 

1. **Topic** - The thing someone speaks of is called the topic. 
1. **Image** - The thing he calls it is the image. 
1. **Points of Comparison** - The ways in which the author claims that the topic and image are similar in some manner are their points of comparison.

In the metaphor below, the speaker describes the woman he loves as a red rose. The woman (his "love") is the **topic**, and "red rose" is the **image**. Beauty and delicacy are the points of comparison that the speaker sees as similarities between both the topic and image. Note, however, that a rose's beauty is not identical to a woman's beauty. Neither are the two kinds of delicacy the same. So these points of comparison are not built upon identical characteristics, but rather upon characteristics that are seen by the writer as similar in some way.

* My love is a red, red rose.

Often, as in the metaphor above, the speaker explicitly states the **topic** and the **image**, but he does not state the points of comparison. The speaker leaves it to the hearer to think of those points of comparison. Because the hearers must do that, the speaker's message tends to be more powerful.

Also in the Bible, normally the **topic** and the **image** are stated clearly, but not the points of comparison. The writer hopes that the audience will understand the points of comparison that are implied.

> Jesus said to them. "I am the bread of life; he who comes to me will not be hungry, and he who believes in me will never be thirsty." (John 6:35 ULB)

In this metaphor, Jesus called himself the bread of life. The **topic** is "I," and the **image** is "bread." Bread is a food that people ate all the time. The point of comparison between bread and Jesus is that people needed break every day for nourishment. In a similar way, people need Jesus every day in order to live spiritually. 

Note that this metaphor is really several metaphors. The first metaphor is that bread is used to represent Jesus. The second metaphor, which is inside the first one, is that physical life represents the spiritual life, which consists of living with God forever. The third metaphor is that eating bread represents benefitting from Jesus, who enables us to live with God forever.

**Purposes of Metaphor**

* One purpose of metaphor is to teach people about something that they do not know (the **topic**) by showing that it is like something that they already do know (the **image**).
* Another purpose is to emphasize that something has a particular quality or to show that it has that quality in an extreme way.
* Another purpose is to lead people to feel the same way about one thing as they would feel about the other.

#### Reasons this is a translation issue

* People may not recognize that something is a metaphor. In other words, they may mistake a metaphor for a literal statement, and thus misunderstand it.
* People may not be familiar with the thing that is used as an image, and so not be able to understand the metaphor. 
* If the topic is not stated, people may not know what the topic is.
* People may not know the points of comparison that the speaker is thinking of and wants them to understand. If they fail to think of these points of comparison, they will not understand the metaphor.

#### Translation Principles

* Make the meaning of a metaphor as clear to the target audience as it was to the original audience.
* Do not make the meaning of a metaphor more clear to the target audience than you think it was to the original audience.

### Examples from the Bible

>Listen to this word, <u>you cows of Bashan</u>, (Amos 4:1 ULB)

In this metaphor Amos speaks to the upper-class women of Samaria (the topic is "you") with as if they were cows (the image). Amos does not say what points of comparison between these women and the cows he has mind, but from the context it seems that he means that both the women and the cows are fat and interested only in eating. 

Note, however, that Amos does not actually mean that the women are cows, for he speaks to them as human beings. 

>And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand. (Isaiah 64:8 ULB)

The example above has two related metaphors. The topics are "we" and "you," and the images are "clay and "potter." The intended point of comparison between a potter and God is the fact that both make what they wish: the potter makes what he wishes out of the clay, and God makes what he wishes out of his people Israel. The point of comparison between the potter's clay and "us" is that both the clay and the people of Israel are made into something different from what they were before. 

>Jesus said to them, "Take heed and beware of <u>the yeast of the Pharisees and Sadducees</u>." The disciples reasoned among themselves and said, "It is because we took no bread." (Matthew 16:6-7 ULB)

Jesus used a metaphor here, but his disciples did not realize it. When he said "yeast," they thought he was talking about bread, but "yeast" was the image in his metaphor, and the topic was the teaching of the Pharisees and Sadducees. Since the disciples (the original audience) did not understand what Jesus meant, it would not be good to state clearly here what Jesus meant.


### Translation Strategies

If people would understand the metaphor in the same way that the original readers probably understood it, go ahead and use it. Be sure to test the translation to make sure that people do understand it.

If people do not or would not understand it, here are some other strategies.

1. If the metaphor is a common expression of a patterned pair of concepts in a biblical language, express the main idea in the simplest way preferred by your language. (See [Biblical Imagery - Common Patterns](../bita-part1/01.md) for lists of some of these patterned pairs of concepts.)
2. If the metaphor seems to be a "live" metaphor, you can translate it literally if you think that the target language also uses this metaphor. If you do this, be sure to test it to make sure that the language community understands it correctly.
3. If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding words such as "like" or "as." See [Simile](../figs-simile/01.md).
4. If the target audience would not know the image, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.
5. If the target audience would not use that image for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times.
6. If the target audience would not know what the topic is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)
7. If the target audience will not know the intended points of comparison between the image and topic, then state them clearly.
8. If none of these strategies is satisfactory, then simply state the idea plainly without using a metaphor.


### Examples of Translation Strategies Applied

1. If the metaphor is a common expression of a patterned pair of concepts in a biblical language, express the main idea in the simplest way preferred by your language. 

    * **Then one of the leaders of the synagogue, named Jairus, came, and when he saw him, <u>fell at his feet</u>.**  (Mark 5:22 ULB)
        * Then one of the leaders of the synagogue, named Jairus, came, and when he saw him, <u>immediately bowed down in front of him</u>.

2. If the metaphor seems to be a "live" metaphor, you can translate it literally if you think that the target language also uses this metaphor. If you do this, be sure to test it to make sure that the language community understands it correctly. 

    * **It was because of your <u>hard hearts</u> that he wrote you this law,**  (Mark 10:5 ULB)
        * It was because of your <u>hard hearts</u> that he wrote you this law, 

There is no change to this one - but it must be tested to make sure that the target audience correctly understands this metaphor.

3. If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding words such as "like" or "as."

    * **And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
        * And yet, Yahweh, you are our father; we are <u>like</u> clay. You are <u>like</u> a potter; and we all are the work of your hand.

4. If the target audience would not know the **image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.

    * **Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
        * Saul, Saul, why do you persecute me? It is hard for you to <u>kick against a pointed stick</u>.

5. If the target audience would not use that **image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times. 

    * **And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
        * "And yet, Yahweh, you are our father; we are the <u>wood</u>. You are our <u>carver</u>; and we all are the work of your hand."
        * "And yet, Yahweh, you are our father; we are the <u>string</u>. You are the <u>weaver</u>; and we all are the work of your hand."

6. If the target audience would not know what the **topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)

    * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
        * Yahweh lives; <u>He is my rock</u>. May he be praised. May the God of my salvation be exalted.

7. If the target audience will not know the intended points of comparison between the image and the topic, then state them clearly.

    * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
        * Yahweh lives; may he be praised because he is the rock <u>under which I can hide from my enemies</u>. May the God of my salvation be exalted.

    * **Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
        * Saul, Saul, why do you persecute me? You <u>fight against me and hurt yourself like an ox that kicks against its owner's pointed stick</u>. 

8. If none of these strategies are satisfactory, then simply state the idea plainly without using a metaphor.

    * **I will make you become <u>fishers of men</u>.** (Mark 1:17 ULB)
        * I will make you become <u>people who gather men</u>.
        * Now you gather fish. I will make you <u>gather people</u>.

_To learn more about specific metaphors read:_

* [Biblical Imagery - Common Patterns](../bita-part1/01.md)

